===
API
===

Indices
=======

.. toctree::

   indices

Indices submodules
------------------


.. automodule:: xclim.indices.generic
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.indices.run_length
   :members:
   :undoc-members:
   :show-inheritance:


Unit handling module
====================

.. automodule:: xclim.core.units
   :members:
   :undoc-members:
   :show-inheritance:


Other utilities
===============

.. automodule:: xclim.core.calendar
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.core.checks
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.core.indicator
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.core.formatting
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.core.utils
   :members:
   :undoc-members:
   :show-inheritance:


Other xclim modules
===================

ensembles module
----------------

.. automodule:: xclim.ensembles
   :members:
   :undoc-members:
   :show-inheritance:


subset module
-------------

.. automodule:: xclim.subset
   :members:
   :undoc-members:
   :show-inheritance:
